=======
History
=======

0.1.0 (2017-04-17)
------------------
* First release on PyPI.

0.1.1 (2017-04-17)
------------------
* Switch to lookmlgen for module name

0.1.2 (2017-04-18)
------------------
* Move primary_key from Field to Dimension
* Remove stub for command line use
* Add docstrings

0.1.3 (2017-04-20)
------------------
* Default sql parameter of fields to ${TABLE}.field_name

0.1.4 (2017-04-20)
------------------
* Support sql_table_name
* Add formatting option for alphabetical view fields or not

0.1.5 (2017-04-24)
------------------
* Rename add_derived_table method to set_derived_table in View

0.1.7 (2017-06-20)
------------------
* Added formatting option to omit timeframe generating params if they're not set
* Update pytest to 3.1.2, cryptography to 1.9, sphinx to 1.6.2

0.1.8 (2017-06-23)
------------------
* Add a description parameter to fields
